Stan Math Library: stan/math/prim/mat/err/check_matching_sizes.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
check_matching_sizes.hpp File Reference
`#include <stan/math/prim/scal/err/domain_error.hpp>`
`#include <stan/math/prim/scal/err/check_size_match.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T_y1 , typename T_y2 >
bool | stan::math::check_matching_sizes (const char *function, const char *name1, const T_y1 &y1, const char *name2, const T_y2 &y2)
| Return `true` if two structures at the same size. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.